@@ -1,6 +1,8 @@
 # --
 # Kernel/Modules/AdminDynamicFieldDropdown.pm - provides a dynamic fields text config view for admins
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: AdminDynamicFieldDropdown.pm,v 1.15 2012-04-18 19:38:01 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,6 +19,9 @@ use Kernel::System::Valid;
 use Kernel::System::CheckItem;
 use Kernel::System::DynamicField;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.15 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -141,7 +146,7 @@ sub _AddAction {
                 Valid      => 0,
                 ResultType => 'HASH',
                 )
-        };
+            };
 
         %DynamicFieldsList = reverse %DynamicFieldsList;
 
@@ -185,7 +190,7 @@ sub _AddAction {
 
     # set errors for possible values entries
     KEY:
-    for my $Key ( sort keys %{$PossibleValues} ) {
+    for my $Key ( keys %{$PossibleValues} ) {
 
         # check for empty original values
         if ( $Key =~ m{\A $Self->{EmptyString} (?: \d+)}smx ) {
@@ -346,18 +351,6 @@ sub _ChangeAction {
         );
     }
 
-    # get dynamic field data
-    my $DynamicFieldData = $Self->{DynamicFieldObject}->DynamicFieldGet(
-        ID => $FieldID,
-    );
-
-    # check for valid dynamic field configuration
-    if ( !IsHashRefWithData($DynamicFieldData) ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => "Could not get data for dynamic field $FieldID",
-        );
-    }
-
     if ( $GetParam{Name} ) {
 
         # check if name is lowercase
@@ -375,7 +368,7 @@ sub _ChangeAction {
                 Valid      => 0,
                 ResultType => 'HASH',
                 )
-        };
+            };
 
         %DynamicFieldsList = reverse %DynamicFieldsList;
 
@@ -389,19 +382,6 @@ sub _ChangeAction {
             $Errors{NameServerError}        = 'ServerError';
             $Errors{NameServerErrorMessage} = 'There is another field with the same name.';
         }
-
-        # if it's an internal field, it's name should not change
-        if (
-            $DynamicFieldData->{InternalField} &&
-            $DynamicFieldsList{ $GetParam{Name} } ne $FieldID
-            )
-        {
-
-            # add server error class
-            $Errors{NameServerError}        = 'ServerError';
-            $Errors{NameServerErrorMessage} = 'The name for this field should not change.';
-            $Param{InternalField}           = $DynamicFieldData->{InternalField};
-        }
     }
 
     if ( $GetParam{FieldOrder} ) {
@@ -432,11 +412,23 @@ sub _ChangeAction {
         );
     }
 
+    # get dynamic field data
+    my $DynamicFieldData = $Self->{DynamicFieldObject}->DynamicFieldGet(
+        ID => $FieldID,
+    );
+
+    # check for valid dynamic field configuration
+    if ( !IsHashRefWithData($DynamicFieldData) ) {
+        return $Self->{LayoutObject}->ErrorScreen(
+            Message => "Could not get data for dynamic field $FieldID",
+        );
+    }
+
     my $PossibleValues = $Self->_GetPossibleValues();
 
     # set errors for possible values entries
     KEY:
-    for my $Key ( sort keys %{$PossibleValues} ) {
+    for my $Key ( keys %{$PossibleValues} ) {
 
         # check for empty original values
         if ( $Key =~ m{\A $Self->{EmptyString} (?: \d+)}smx ) {
@@ -548,7 +540,6 @@ sub _ShowScreen {
         Name          => 'FieldOrder',
         SelectedValue => $Param{FieldOrder} || 1,
         PossibleNone  => 0,
-        Translation   => 0,
         Class         => 'W50pc Validate_Number',
     );
 
@@ -647,7 +638,7 @@ sub _ShowScreen {
     # check and build the Default Value list based on Possible Values
     my %DefaultValuesList;
     POSSIBLEVALUE:
-    for my $ValueItem ( sort keys %PossibleValues ) {
+    for my $ValueItem ( keys %PossibleValues ) {
         next POSSIBLEVALUE if !defined $ValueItem;
         next POSSIBLEVALUE if !defined $PossibleValues{$ValueItem};
         $DefaultValuesList{$ValueItem} = $PossibleValues{$ValueItem}
@@ -699,17 +690,6 @@ sub _ShowScreen {
 
     my $Link = $Param{Link} || '';
 
-    my $ReadonlyInternalField = '';
-
-    # Internal fields can not be deleted and name should not change.
-    if ( $Param{InternalField} ) {
-        $Self->{LayoutObject}->Block(
-            Name => 'InternalField',
-            Data => {%Param},
-        );
-        $ReadonlyInternalField = 'readonly="readonly"';
-    }
-
     # generate output
     $Output .= $Self->{LayoutObject}->Output(
         TemplateFile => 'AdminDynamicFieldDropdown',
@@ -721,7 +701,6 @@ sub _ShowScreen {
             DefaultValueStrg       => $DefaultValueStrg,
             PossibleNoneStrg       => $PossibleNoneStrg,
             TranslatableValuesStrg => $TranslatableValuesStrg,
-            ReadonlyInternalField  => $ReadonlyInternalField,
             Link                   => $Link,
             }
     );
