@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketWatcher.pm - a ticketwatcher module
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketWatcher.pm,v 1.15.2.1 2012-01-20 10:26:39 jh Exp $
+# $Id: AgentTicketWatcher.pm,v 1.18 2012-01-24 00:08:45 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,9 +13,10 @@ package Kernel::Modules::AgentTicketWatcher;
 
 use strict;
 use warnings;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.15.2.1 $) [1];
+$VERSION = qw($Revision: 1.18 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -64,11 +65,44 @@ sub Run {
         return $Self->{Layout}->NoPermission();
     }
 
+    # get ACL restrictions
+    $Self->{TicketObject}->TicketAcl(
+        Data          => '-',
+        TicketID      => $Self->{TicketID},
+        ReturnType    => 'Action',
+        ReturnSubType => '-',
+        UserID        => $Self->{UserID},
+    );
+    my %AclAction = $Self->{TicketObject}->TicketAclActionData();
+
+    # check if ACL resctictions if exist
+    if ( IsHashRefWithData( \%AclAction ) ) {
+
+        # show error screen if ACL prohibits this action
+        if ( defined $AclAction{ $Self->{Action} } && $AclAction{ $Self->{Action} } eq '0' ) {
+            return $Self->{LayoutObject}->NoPermission( WithHeader => 'yes' );
+        }
+    }
+
     # ------------------------------------------------------------ #
     # subscribe a ticket
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Subscribe' ) {
 
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
+        # Checks if the user has permissions to see the ticket.
+        #   This is needed because watching grants ro permissions (depending on configuration).
+        my $Access = $Self->{TicketObject}->TicketPermission(
+            Type     => 'ro',
+            TicketID => $Self->{TicketID},
+            UserID   => $Self->{UserID},
+        );
+        if (!$Access) {
+            return $Self->{LayoutObject}->NoPermission( WithHeader => 'yes' );
+        }
+
         # set subscribe
         my $Subscribe = $Self->{TicketObject}->TicketWatchSubscribe(
             TicketID    => $Self->{TicketID},
@@ -88,6 +122,12 @@ sub Run {
     # unsubscribe a ticket
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Unsubscribe' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
+        # We don't need a permission check here as we will remove
+        #   permissions by unsubscribing.
         my $Unsubscribe = $Self->{TicketObject}->TicketWatchUnsubscribe(
             TicketID    => $Self->{TicketID},
             WatchUserID => $Self->{UserID},
