@@ -1,8 +1,8 @@
 # --
 # Kernel/Output/HTML/ArticleAttachmentDownload.pm
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
 # --
-# $Id: ArticleAttachmentDownload.pm,v 1.12 2009/12/07 14:59:38 mg Exp $
+# $Id: ArticleAttachmentDownload.pm,v 1.15.2.1 2013-01-02 13:02:46 mn Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.12 $) [1];
+$VERSION = qw($Revision: 1.15.2.1 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -46,7 +46,7 @@ sub Run {
     my $Type = $Self->{ConfigObject}->Get('AttachmentDownloadType') || 'attachment';
 
     # if attachment will be forced to download, don't open a new download window!
-    my $Target = '';
+    my $Target = 'target="AttachmentWindow" ';
     if ( $Type =~ /inline/i ) {
         $Target = 'target="attachment" ';
     }
