@@ -2,7 +2,7 @@
 # Kernel/Output/HTML/TicketMenuLock.pm
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: TicketMenuLock.pm,v 1.18.2.1 2012-04-17 15:45:50 des Exp $
+# $Id: TicketMenuLock.pm,v 1.21 2012-04-17 15:48:19 des Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.18.2.1 $) [1];
+$VERSION = qw($Revision: 1.21 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -82,8 +82,9 @@ sub Run {
             %{ $Param{Ticket} },
             %Param,
             Name        => 'Unlock',
-            Description => 'Unlock to give it back to the queue!',
-            Link        => 'Action=AgentTicketLock;Subaction=Unlock;TicketID=$QData{"TicketID"}',
+            Description => 'Unlock to give it back to the queue',
+            Link =>
+                'Action=AgentTicketLock;Subaction=Unlock;TicketID=$QData{"TicketID"};$QEnv{"ChallengeTokenParam"}',
         };
     }
 
@@ -93,8 +94,9 @@ sub Run {
         %{ $Param{Ticket} },
         %Param,
         Name        => 'Lock',
-        Description => 'Lock it to work on it!',
-        Link        => 'Action=AgentTicketLock;Subaction=Lock;TicketID=$QData{"TicketID"}',
+        Description => 'Lock it to work on it',
+        Link =>
+            'Action=AgentTicketLock;Subaction=Lock;TicketID=$QData{"TicketID"};$QEnv{"ChallengeTokenParam"}',
     };
 }
 
