@@ -1,6 +1,8 @@
 # --
 # Kernel/System/Email/Sendmail.pm - the global email send module
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: Sendmail.pm,v 1.33 2011-08-12 09:06:15 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +14,9 @@ package Kernel::System::Email::Sendmail;
 use strict;
 use warnings;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.33 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -72,9 +77,7 @@ sub Send {
 
     # invoke sendmail in order to send off mail, catching errors in a temporary file
     my $FH;
-    ## no critic
     if ( !open( $FH, '|-', "$Sendmail $Arg " ) ) {
-        ## use critic
         $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "Can't send message: $!!",
@@ -83,7 +86,7 @@ sub Send {
     }
 
     # switch filehandle to utf8 mode if utf-8 is used
-    binmode $FH, ':utf8';    ## no critic
+    binmode $FH, ':utf8';
 
     print $FH ${ $Param{Header} };
     print $FH "\n";
