@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Web/Request.pm - a wrapper for CGI.pm or Apache::Request.pm
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Request.pm,v 1.37.2.2 2011/11/21 10:20:32 mg Exp $
+# $Id: Request.pm,v 1.41.2.1 2012-12-03 11:42:02 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,14 +14,16 @@ package Kernel::System::Web::Request;
 use strict;
 use warnings;
 
+use File::Path qw();
+
 use Kernel::System::CheckItem;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.37.2.2 $) [1];
+$VERSION = qw($Revision: 1.41.2.1 $) [1];
 
 =head1 NAME
 
-Kernel::System::Web::Request - global cgi param interface
+Kernel::System::Web::Request - global CGI interface
 
 =head1 SYNOPSIS
 
@@ -61,9 +63,19 @@ create param object
         LogObject    => $LogObject,
         EncodeObject => $EncodeObject,
         MainObject   => $MainObject,
-
+        WebRequest   => CGI::Fast->new(), # optional, e. g. if fast cgi is used
     );
 
+If Kernel::System::Web::Request is instantiated several times, they will share the
+same CGI data (this can be helpful in filters which do not have access to the
+ParamObject, for example.
+
+If you need to reset the CGI data before creating a new instance, use
+
+    CGI::initialize_globals();
+
+before calling Kernel::System::Web::Request->new();
+
 =cut
 
 sub new {
@@ -269,11 +281,11 @@ sub GetUploadAll {
         # delete upload dir if exists
         my $Path = "/tmp/$$";
         if ( -d $Path ) {
-            File::Path::rmtree( [$Path] );
+            File::Path::remove_tree($Path);
         }
 
         # create upload dir
-        File::Path::mkpath( [$Path], 0, 0700 );
+        File::Path::make_path( $Path, { mode => 0700 } );
 
         $Content = "$Path/$NewFileName";
 
@@ -284,8 +296,7 @@ sub GetUploadAll {
         close $Out;
     }
 
-    # check if content is there, IE is always sending file uploades
-    # without content
+    # Check if content is there, IE is always sending file uploads without content.
     return if !$Content;
 
     my $ContentType = $Self->_GetUploadInfo(
@@ -372,6 +383,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.37.2.2 $ $Date: 2011/11/21 10:20:32 $
+$Revision: 1.41.2.1 $ $Date: 2012-12-03 11:42:02 $
 
 =cut
