@@ -3,7 +3,7 @@
 # bin/otrs.CheckModules.pl - to check needed cpan framework modules
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: otrs.CheckModules.pl,v 1.14.2.4 2012-12-11 16:04:25 mg Exp $
+# $Id: otrs.CheckModules.pl,v 1.36.2.1 2012-12-11 16:04:14 mg Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -38,6 +38,11 @@ my @NeededModules = (
         Module   => 'Crypt::PasswdMD5',
         Required => 1,
     },
+    {
+        Module   => 'Crypt::SSLeay',
+        Required => 0,
+        Comment  => 'Required for Generic Interface SOAP SSL connections.',
+    },
     {
         Module   => 'CSS::Minifier',
         Required => 1,
@@ -59,6 +64,28 @@ my @NeededModules = (
         Required => 0,
         Comment  => 'Required to connect to a MySQL database.',
     },
+    {
+        Module       => 'DBD::ODBC',
+        Required     => 0,
+        NotSupported => [
+            {
+                Version => '1.23',
+                Comment =>
+                    'This version is broken and not useable! Please upgrade to a higher version.',
+            },
+        ],
+        Comment => 'Required to connect to a MS-SQL database.',
+    },
+    {
+        Module   => 'DBD::Oracle',
+        Required => 0,
+        Comment  => 'Required to connect to a Oracle database.',
+    },
+    {
+        Module   => 'DBD::Pg',
+        Required => 0,
+        Comment  => 'Required to connect to a PostgreSQL database.',
+    },
     {
         Module   => 'Digest::MD5',
         Required => 1,
@@ -69,12 +96,21 @@ my @NeededModules = (
         Required => 1,
         Comment  => 'Required to authenticate users and customers using SHA-1 or SHA-2 methods',
     },
+    {
+        Module   => 'Digest::SHA',
+        Required => 0,
+        Comment  => 'Recommended for faster xml handling.',
+    },
     {
         Module   => 'Encode::HanExtra',
         Version  => '0.23',
         Required => 0,
         Comment  => 'Required to handle mails with several Chinese character sets.',
     },
+    {
+        Module   => 'Encode::Locale',
+        Required => 1,
+    },
     {
         Module   => 'GD',
         Required => 0,
@@ -130,10 +166,14 @@ my @NeededModules = (
             {
                 Module   => 'JSON::XS',
                 Required => 0,
-                Comment  => 'Install it for faster AJAX/JavaScript handling.',
+                Comment  => 'Recommended for faster AJAX/JavaScript handling.',
             },
         ],
     },
+    {
+        Module   => 'Locale::Codes',
+        Required => 1,
+    },
     {
         Module   => 'LWP::UserAgent',
         Required => 1,
@@ -154,6 +194,18 @@ my @NeededModules = (
             },
         ],
     },
+    {
+        Module   => 'Mail::IMAPClient',
+        Comment  => 'Required for IMAP TLS connections.',
+        Required => 0,
+        Depends  => [
+            {
+                Module   => 'IO::Socket::SSL',
+                Required => 0,
+                Comment  => 'Required for IMAP TLS connections.',
+            },
+        ],
+    },
     {
         Module   => 'MIME::Base64',
         Required => 1,
@@ -246,6 +298,11 @@ my @NeededModules = (
         Required => 0,
         Comment  => 'Required for directory authentication.',
     },
+    {
+        Module   => 'Net::SSL',
+        Required => 0,
+        Comment  => 'Required for Generic Interface SOAP SSL connections.',
+    },
     {
         Module       => 'PDF::API2',
         Version      => '0.57',
@@ -302,6 +359,18 @@ my @NeededModules = (
                     'This version is broken and not useable! Please use another version.',
             },
         ],
+        Depends => [
+            {
+                Module   => 'version',
+                Required => 0,
+                Comment  => 'Required for SOAP::Lite.',
+            },
+            {
+                Module   => 'Class::Inspector',
+                Required => 0,
+                Comment  => 'Required for SOAP::Lite.',
+            },
+        ],
     },
     {
         Module   => 'Text::CSV',
@@ -316,7 +385,7 @@ my @NeededModules = (
             {
                 Module   => 'Text::CSV_XS',
                 Required => 0,
-                Comment  => 'Optional, install it for faster CSV handling.',
+                Comment  => 'Recommended for faster CSV handling.',
             },
         ],
     },
@@ -328,10 +397,78 @@ my @NeededModules = (
     {
         Module   => 'XML::Parser',
         Required => 0,
-        Comment  => 'Required for faster xml handling.'
+        Comment  => 'Recommended for faster xml handling.',
+    },
+    {
+        Module   => 'HTTP::Message',
+        Required => 1,
+        Comment  => 'Required for HTTP communication.',
+        Depends  => [
+            {
+                Module       => 'HTTP::Headers',
+                Required     => 1,
+                Comment      => 'Required for HTTP communication.',
+                NotSupported => [
+                    {
+                        Version => '1.64',
+                        Comment =>
+                            'This version is broken and not useable! '
+                            . 'Please upgrade to a higher version.',
+                    },
+                ],
+            },
+        ],
+        NotSupported => [
+            {
+                Version => '1.57',
+                Comment =>
+                    'This version is broken and not useable! '
+                    . 'Please upgrade to a higher version.',
+            },
+        ],
+    },
+    {
+        Module       => 'URI',
+        Required     => 1,
+        Comment      => 'Handles encoding and decoding of URLs',
+        NotSupported => [
+            {
+                Version => '1.35',
+                Comment =>
+                    'This version is broken and not useable! Please upgrade to a higher version.',
+            },
+        ],
+        Depends => [
+            {
+                Module   => 'URI::Escape',
+                Required => 1,
+                Comment  => 'Handles encoding and decoding of URLs.',
+            },
+        ],
+    },
+    {
+        Module   => 'Scalar::Util',
+        Required => 1,
     },
 );
 
+# if we're on Windows we need some additional modules
+if ( $^O eq "MSWin32" ) {
+    my @WindowsModules = (
+        {
+            Module   => 'Win32::Daemon',
+            Required => 1,
+            Comment  => 'For running the OTRS Scheduler Service.',
+        },
+        {
+            Module   => 'Win32::Service',
+            Required => 1,
+            Comment  => 'For running the OTRS Scheduler Service.',
+        },
+    );
+    push @NeededModules, @WindowsModules;
+}
+
 # try to load modules
 my $Depends = 0;
 foreach my $Module (@NeededModules) {
@@ -347,7 +484,7 @@ sub _Check {
     }
     print "o $Module->{Module}";
     my $Length = length( $Module->{Module} ) + ( $Depends * 3 );
-    for ( $Length .. 30 ) {
+    for ( $Length .. 32 ) {
         print ".";
     }
     if ( eval "require $Module->{Module}" ) {
