@@ -1,7 +1,9 @@
 #!/usr/bin/perl
 # --
 # scripts/backup.pl - the backup script
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
+# --
+# $Id: backup.pl,v 1.25.4.2 2013-01-18 14:52:57 mg Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -15,20 +17,21 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
-use strict;
-use warnings;
-
 # use ../ as lib location
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
 use lib dirname($RealBin) . "/Kernel/cpan-lib";
 
+use strict;
+use warnings;
+
 use vars qw($VERSION);
+$VERSION = qw($Revision: 1.25.4.2 $) [1];
 
 use Getopt::Std;
 use Kernel::Config;
@@ -41,14 +44,14 @@ use Date::Pcalc qw(Today Today_and_Now Add_Delta_Days);
 
 # get options
 my %Opts;
-my $Compress    = '';
-my $CompressCMD = '';
-my $DB          = '';
-my $DBDump      = '';
+my $Compress     = '';
+my $CompressCMD  = '';
+my $DB           = '';
+my $DBDump       = '';
 getopt( 'hcrtd', \%Opts );
 if ( exists $Opts{h} ) {
     print "backup.pl <Revision $VERSION> - backup script\n";
-    print "Copyright (C) 2001-2013 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2013 OTRS AG, http://otrs.org/\n";
     print
         "usage: backup.pl -d /data_backup_dir/ [-c gzip|bzip2] [-r 30] [-t fullbackup|nofullbackup|dbonly]\n";
     exit 1;
@@ -128,7 +131,7 @@ else {
 # check needed programs
 for my $CMD ( 'cp', 'tar', $DBDump, $CompressCMD ) {
     my $Installed = 0;
-    open my $In, '-|', "which $CMD";    ## no critic
+    open my $In, "which $CMD | ";
     while (<$In>) {
         $Installed = 1;
     }
@@ -157,7 +160,7 @@ if ( $Opts{r} ) {
 
     for my $Directory (@Directories) {
         my $Leave = 0;
-        for my $Data ( sort keys %LeaveBackups ) {
+        for my $Data ( keys %LeaveBackups ) {
             if ( $Directory =~ m/$Data/ ) {
                 $Leave = 1;
             }
@@ -202,7 +205,7 @@ if ( !mkdir($Directory) ) {
 print "Backup $Directory/Config.tar.gz ... ";
 if (
     !system(
-        "tar -czf $Directory/Config.tar.gz Kernel/Config*"
+        "tar -czf $Directory/Config.tar.gz Kernel/Config.pm Kernel/Config/Files/ZZZA*.pm Kernel/Config/GenericAgen*.pm"
     )
     )
 {
